## 沪深港通股票列表

接口：stock_hsgt，可以通过数据工具调试和查看数据。

描述：获取沪深港通股票列表

权限：3000积分起

提示：每天上午9:20更新，单次请求最大返回2000行数据，可根据类型循环提取,本接口数据从20250812开始

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期（格式：YYYYMMDD） |
| type | str | Y | 类型（参考下表） |
| start_date | str | N | 开始时间 |
| end_date | str | N | 结束时间 |

类型说明如下：

| 类型 | 类型名称 |
| --- | --- |
| HK_SZ | 深股通(港>深) |
| SZ_HK | 港股通(深>港) |
| HK_SH | 沪股通(港>沪) |
| SH_HK | 港股通(沪>港) |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| type | str | Y | 类型 |
| name | str | Y | 股票名称 |
| type_name | str | Y | 类型名称 |

接口用法

```python
pro = ts.pro_api()

#获取20250813日深股通的股票列表
df = pro.stock_hsgt(trade_date='20250813',type='HK_SZ')
```

数据样例

```python
ts_code trade_date   type     name type_name
0    001258.SZ   20250813  HK_SZ     立新能源  深股通(港>深)
```